EXPORTS
	??1CMMFFormatRead@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CMMFFormatRead::~CMMFFormatRead(void)
	??1CMMFFormatWrite@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CMMFFormatWrite::~CMMFFormatWrite(void)
	?AlignToSample@@YAIIIIIW4EMMFRound@@H@Z @ 3 NONAME ; unsigned int __cdecl AlignToSample(unsigned int,unsigned int,unsigned int,unsigned int,enum EMMFRound,int)
	?AlignToSample@@YAIIIW4EMMFRound@@@Z @ 4 NONAME ; unsigned int __cdecl AlignToSample(unsigned int,unsigned int,enum EMMFRound)
	?BufferEmptiedL@CMMFFormatWrite@@UAEXPAVCMMFBuffer@@@Z @ 5 NONAME ; public: virtual void __thiscall CMMFFormatWrite::BufferEmptiedL(class CMMFBuffer *)
	?BufferFilledL@CMMFFormatRead@@UAEXPAVCMMFBuffer@@@Z @ 6 NONAME ; public: virtual void __thiscall CMMFFormatRead::BufferFilledL(class CMMFBuffer *)
	?BytesPerSecond@CMMFFormatWrite@@UAE_JXZ @ 7 NONAME ; public: virtual long long  __thiscall CMMFFormatWrite::BytesPerSecond(void)
	?CalculateFrameSize@CMMFFormatRead@@MAEXI@Z @ 8 NONAME ; protected: virtual void __thiscall CMMFFormatRead::CalculateFrameSize(unsigned int)
	?CalculateFrameSize@CMMFFormatWrite@@MAEXI@Z @ 9 NONAME ; protected: virtual void __thiscall CMMFFormatWrite::CalculateFrameSize(unsigned int)
	?CalculateFrameTimeInterval@CMMFFormatRead@@MAEXXZ @ 10 NONAME ; protected: virtual void __thiscall CMMFFormatRead::CalculateFrameTimeInterval(void)
	?CalculateFrameTimeInterval@CMMFFormatWrite@@MAEXXZ @ 11 NONAME ; protected: virtual void __thiscall CMMFFormatWrite::CalculateFrameTimeInterval(void)
	?ConstructL@CMMFFormatRead@@MAEXPAVMDataSource@@@Z @ 12 NONAME ; protected: virtual void __thiscall CMMFFormatRead::ConstructL(class MDataSource *)
	?ConstructL@CMMFFormatWrite@@MAEXPAVMDataSink@@@Z @ 13 NONAME ; protected: virtual void __thiscall CMMFFormatWrite::ConstructL(class MDataSink *)
	?CreateSinkBufferL@CMMFFormatWrite@@UAEPAVCMMFBuffer@@VTMediaId@@AAH@Z @ 14 NONAME ; public: virtual class CMMFBuffer * __thiscall CMMFFormatWrite::CreateSinkBufferL(class TMediaId,int &)
	?CreateSinkBufferOfSizeL@CMMFFormatWrite@@IAEPAVCMMFDataBuffer@@I@Z @ 15 NONAME ; protected: class CMMFDataBuffer * __thiscall CMMFFormatWrite::CreateSinkBufferOfSizeL(unsigned int)
	?CreateSourceBufferL@CMMFFormatRead@@UAEPAVCMMFBuffer@@VTMediaId@@AAH@Z @ 16 NONAME ; public: virtual class CMMFBuffer * __thiscall CMMFFormatRead::CreateSourceBufferL(class TMediaId,int &)
	?CreateSourceBufferL@CMMFFormatRead@@UAEPAVCMMFBuffer@@VTMediaId@@AAV2@AAH@Z @ 17 NONAME ; public: virtual class CMMFBuffer * __thiscall CMMFFormatRead::CreateSourceBufferL(class TMediaId,class CMMFBuffer &,int &)
	?CreateSourceBufferOfSizeL@CMMFFormatRead@@IAEPAVCMMFDataBuffer@@I@Z @ 18 NONAME ; protected: class CMMFDataBuffer * __thiscall CMMFFormatRead::CreateSourceBufferOfSizeL(unsigned int)
	?DataPosition@@YAIVTTimeIntervalMicroSeconds@@0I@Z @ 19 NONAME ; unsigned int __cdecl DataPosition(class TTimeIntervalMicroSeconds,class TTimeIntervalMicroSeconds,unsigned int)
	?DataPosition@@YAIVTTimeIntervalMicroSeconds@@III@Z @ 20 NONAME ; unsigned int __cdecl DataPosition(class TTimeIntervalMicroSeconds,unsigned int,unsigned int,unsigned int)
	?DoReadL@CMMFFormatRead@@IAEXH@Z @ 21 NONAME ; protected: void __thiscall CMMFFormatRead::DoReadL(int)
	?DoReadL@CMMFFormatWrite@@IAEXH@Z @ 22 NONAME ; protected: void __thiscall CMMFFormatWrite::DoReadL(int)
	?DoWriteL@CMMFFormatWrite@@IAEXH@Z @ 23 NONAME ; protected: void __thiscall CMMFFormatWrite::DoWriteL(int)
	?Duration@CMMFFormatRead@@UBE?AVTTimeIntervalMicroSeconds@@VTMediaId@@@Z @ 24 NONAME ; public: virtual class TTimeIntervalMicroSeconds  __thiscall CMMFFormatRead::Duration(class TMediaId)const 
	?Duration@CMMFFormatWrite@@UBE?AVTTimeIntervalMicroSeconds@@VTMediaId@@@Z @ 25 NONAME ; public: virtual class TTimeIntervalMicroSeconds  __thiscall CMMFFormatWrite::Duration(class TMediaId)const 
	?DurationCalculation@@YA?AVTTimeIntervalMicroSeconds@@II@Z @ 26 NONAME ; class TTimeIntervalMicroSeconds  __cdecl DurationCalculation(unsigned int,unsigned int)
	?DurationCalculation@@YA?AVTTimeIntervalMicroSeconds@@IIII@Z @ 27 NONAME ; class TTimeIntervalMicroSeconds  __cdecl DurationCalculation(unsigned int,unsigned int,unsigned int,unsigned int)
	?DurationCalculation@@YA?AVTTimeIntervalMicroSeconds@@IV1@I@Z @ 28 NONAME ; class TTimeIntervalMicroSeconds  __cdecl DurationCalculation(unsigned int,class TTimeIntervalMicroSeconds,unsigned int)
	?EmptyBufferL@CMMFFormatWrite@@UAEXPAVCMMFBuffer@@PAVMDataSource@@VTMediaId@@@Z @ 29 NONAME ; public: virtual void __thiscall CMMFFormatWrite::EmptyBufferL(class CMMFBuffer *,class MDataSource *,class TMediaId)
	?FillBufferL@CMMFFormatRead@@UAEXPAVCMMFBuffer@@PAVMDataSink@@VTMediaId@@@Z @ 30 NONAME ; public: virtual void __thiscall CMMFFormatRead::FillBufferL(class CMMFBuffer *,class MDataSink *,class TMediaId)
	?FrameSizeCalculation@@YAIIII@Z @ 31 NONAME ; unsigned int __cdecl FrameSizeCalculation(unsigned int,unsigned int,unsigned int)
	?FrameTimeInterval@CMMFFormatRead@@UBE?AVTTimeIntervalMicroSeconds@@VTMediaId@@@Z @ 32 NONAME ; public: virtual class TTimeIntervalMicroSeconds  __thiscall CMMFFormatRead::FrameTimeInterval(class TMediaId)const 
	?FrameTimeInterval@CMMFFormatWrite@@UBE?AVTTimeIntervalMicroSeconds@@VTMediaId@@@Z @ 33 NONAME ; public: virtual class TTimeIntervalMicroSeconds  __thiscall CMMFFormatWrite::FrameTimeInterval(class TMediaId)const 
	?FrameTimeIntervalCalculation@@YA?AVTTimeIntervalMicroSeconds@@II@Z @ 34 NONAME ; class TTimeIntervalMicroSeconds  __cdecl FrameTimeIntervalCalculation(unsigned int,unsigned int)
	?FrameTimeIntervalCalculation@@YA?AVTTimeIntervalMicroSeconds@@IIII@Z @ 35 NONAME ; class TTimeIntervalMicroSeconds  __cdecl FrameTimeIntervalCalculation(unsigned int,unsigned int,unsigned int,unsigned int)
	?GetAudioSettingsFromDevice@@YAXPAVCMMFDevSound@@AAI1AAVTFourCC@@@Z @ 36 NONAME ; void __cdecl GetAudioSettingsFromDevice(class CMMFDevSound *,unsigned int &,unsigned int &,class TFourCC &)
	?GetSupportedNumChannelsL@CMMFFormatRead@@UAEXAAV?$RArray@I@@@Z @ 37 NONAME ; public: virtual void __thiscall CMMFFormatRead::GetSupportedNumChannelsL(class RArray<unsigned int> &)
	?GetSupportedNumChannelsL@CMMFFormatWrite@@UAEXAAV?$RArray@I@@@Z @ 38 NONAME ; public: virtual void __thiscall CMMFFormatWrite::GetSupportedNumChannelsL(class RArray<unsigned int> &)
	?GetSupportedSampleRatesL@CMMFFormatRead@@UAEXAAV?$RArray@I@@@Z @ 39 NONAME ; public: virtual void __thiscall CMMFFormatRead::GetSupportedSampleRatesL(class RArray<unsigned int> &)
	?GetSupportedSampleRatesL@CMMFFormatWrite@@UAEXAAV?$RArray@I@@@Z @ 40 NONAME ; public: virtual void __thiscall CMMFFormatWrite::GetSupportedSampleRatesL(class RArray<unsigned int> &)
	?IsMaxClipLengthExceeded@CMMFFormatWrite@@MAEHABVCMMFBuffer@@@Z @ 41 NONAME ; protected: virtual int __thiscall CMMFFormatWrite::IsMaxClipLengthExceeded(class CMMFBuffer const &)
	?IsValidSampleRate@CMMFFormatWrite@@MAEHI@Z @ 42 NONAME ; protected: virtual int __thiscall CMMFFormatWrite::IsValidSampleRate(unsigned int)
	?NegotiateSourceBufferL@CMMFFormatRead@@MAEXAAVCMMFBuffer@@@Z @ 43 NONAME ; protected: virtual void __thiscall CMMFFormatRead::NegotiateSourceBufferL(class CMMFBuffer &)
	?NegotiateSourceL@CMMFFormatRead@@UAEXAAVMDataSink@@@Z @ 44 NONAME ; public: virtual void __thiscall CMMFFormatRead::NegotiateSourceL(class MDataSink &)
	?PositionL@CMMFFormatRead@@UAE?AVTTimeIntervalMicroSeconds@@XZ @ 45 NONAME ; public: virtual class TTimeIntervalMicroSeconds  __thiscall CMMFFormatRead::PositionL(void)
	?PositionL@CMMFFormatWrite@@UAE?AVTTimeIntervalMicroSeconds@@XZ @ 46 NONAME ; public: virtual class TTimeIntervalMicroSeconds  __thiscall CMMFFormatWrite::PositionL(void)
	?SendEventToClient@CMMFFormatRead@@UAEHABVTMMFEvent@@@Z @ 47 NONAME ; public: virtual int __thiscall CMMFFormatRead::SendEventToClient(class TMMFEvent const &)
	?SendEventToClient@CMMFFormatWrite@@UAEHABVTMMFEvent@@@Z @ 48 NONAME ; public: virtual int __thiscall CMMFFormatWrite::SendEventToClient(class TMMFEvent const &)
	?SetMaximumClipSizeL@CMMFFormatWrite@@UAEXH@Z @ 49 NONAME ; public: virtual void __thiscall CMMFFormatWrite::SetMaximumClipSizeL(int)
	?SetNumChannels@CMMFFormatRead@@UAEHI@Z @ 50 NONAME ; public: virtual int __thiscall CMMFFormatRead::SetNumChannels(unsigned int)
	?SetNumChannels@CMMFFormatWrite@@UAEHI@Z @ 51 NONAME ; public: virtual int __thiscall CMMFFormatWrite::SetNumChannels(unsigned int)
	?SetPositionL@CMMFFormatRead@@UAEXABVTTimeIntervalMicroSeconds@@@Z @ 52 NONAME ; public: virtual void __thiscall CMMFFormatRead::SetPositionL(class TTimeIntervalMicroSeconds const &)
	?SetPositionL@CMMFFormatWrite@@UAEXABVTTimeIntervalMicroSeconds@@@Z @ 53 NONAME ; public: virtual void __thiscall CMMFFormatWrite::SetPositionL(class TTimeIntervalMicroSeconds const &)
	?SetSampleRate@CMMFFormatRead@@UAEHI@Z @ 54 NONAME ; public: virtual int __thiscall CMMFFormatRead::SetSampleRate(unsigned int)
	?SetSampleRate@CMMFFormatWrite@@UAEHI@Z @ 55 NONAME ; public: virtual int __thiscall CMMFFormatWrite::SetSampleRate(unsigned int)
	?SetSourceDataTypeCode@CMMFFormatRead@@UAEHVTFourCC@@VTMediaId@@@Z @ 56 NONAME ; public: virtual int __thiscall CMMFFormatRead::SetSourceDataTypeCode(class TFourCC,class TMediaId)
	?SinkDataTypeCode@CMMFFormatWrite@@UAE?AVTFourCC@@VTMediaId@@@Z @ 57 NONAME ; public: virtual class TFourCC  __thiscall CMMFFormatWrite::SinkDataTypeCode(class TMediaId)
	?SinkPauseL@CMMFFormatWrite@@UAEXXZ @ 58 NONAME ; public: virtual void __thiscall CMMFFormatWrite::SinkPauseL(void)
	?SinkPlayL@CMMFFormatWrite@@UAEXXZ @ 59 NONAME ; public: virtual void __thiscall CMMFFormatWrite::SinkPlayL(void)
	?SinkPrimeL@CMMFFormatWrite@@UAEXXZ @ 60 NONAME ; public: virtual void __thiscall CMMFFormatWrite::SinkPrimeL(void)
	?SinkStopL@CMMFFormatWrite@@UAEXXZ @ 61 NONAME ; public: virtual void __thiscall CMMFFormatWrite::SinkStopL(void)
	?SinkThreadLogoff@CMMFFormatWrite@@UAEXXZ @ 62 NONAME ; public: virtual void __thiscall CMMFFormatWrite::SinkThreadLogoff(void)
	?SinkThreadLogon@CMMFFormatWrite@@UAEHAAVMAsyncEventHandler@@@Z @ 63 NONAME ; public: virtual int __thiscall CMMFFormatWrite::SinkThreadLogon(class MAsyncEventHandler &)
	?SourceDataTypeCode@CMMFFormatRead@@UAE?AVTFourCC@@VTMediaId@@@Z @ 64 NONAME ; public: virtual class TFourCC  __thiscall CMMFFormatRead::SourceDataTypeCode(class TMediaId)
	?SourcePauseL@CMMFFormatRead@@UAEXXZ @ 65 NONAME ; public: virtual void __thiscall CMMFFormatRead::SourcePauseL(void)
	?SourcePlayL@CMMFFormatRead@@UAEXXZ @ 66 NONAME ; public: virtual void __thiscall CMMFFormatRead::SourcePlayL(void)
	?SourcePrimeL@CMMFFormatRead@@UAEXXZ @ 67 NONAME ; public: virtual void __thiscall CMMFFormatRead::SourcePrimeL(void)
	?SourceStopL@CMMFFormatRead@@UAEXXZ @ 68 NONAME ; public: virtual void __thiscall CMMFFormatRead::SourceStopL(void)
	?SourceThreadLogoff@CMMFFormatRead@@UAEXXZ @ 69 NONAME ; public: virtual void __thiscall CMMFFormatRead::SourceThreadLogoff(void)
	?SourceThreadLogon@CMMFFormatRead@@UAEHAAVMAsyncEventHandler@@@Z @ 70 NONAME ; public: virtual int __thiscall CMMFFormatRead::SourceThreadLogon(class MAsyncEventHandler &)
	?Streams@CMMFFormatRead@@UBEIVTUid@@@Z @ 71 NONAME ; public: virtual unsigned int __thiscall CMMFFormatRead::Streams(class TUid)const 
	?CropL@CMMFFormatWrite@@UAEXVTTimeIntervalMicroSeconds@@H@Z @ 72 NONAME ; public: virtual void __thiscall CMMFFormatWrite::CropL(class TTimeIntervalMicroSeconds,int)
	?CustomInterface@CMMFFormatRead@@UAEPAXVTUid@@@Z @ 73 NONAME ; void * CMMFFormatRead::CustomInterface(class TUid)

